@@ -95,18 +95,19 @@ pub async fn p2p_put_all_batch(env: EnvWrite, rx: tokio::sync::mpsc::Receiver<P2
 }
 
 /// Helper function to get all the peer data from this conductor
-pub fn all_agent_infos(env: EnvRead) -> StateQueryResult<Vec<AgentInfoSigned>> {
-    fresh_reader!(env, |r| Ok(r.p2p_list_agents()?))
+pub async fn all_agent_infos(env: EnvRead) -> StateQueryResult<Vec<AgentInfoSigned>> {
+    env.async_reader(|r| Ok(r.p2p_list_agents()?)).await
 }
 
 /// Helper function to get a single agent info
-pub fn get_single_agent_info(
+pub async fn get_single_agent_info(
     env: EnvRead,
     _space: DnaHash,
     agent: AgentPubKey,
 ) -> StateQueryResult<Option<AgentInfoSigned>> {
     let agent = agent.to_kitsune();
-    fresh_reader!(env, |r| Ok(r.p2p_get_agent(&agent)?))
+    env.async_reader(move |r| Ok(r.p2p_get_agent(&agent)?))
+        .await
 }
 
 /// Interconnect every provided pair of conductors via their peer store databases
@@ -117,12 +118,18 @@ pub async fn exchange_peer_info(envs: Vec<EnvWrite>) {
             if i == j {
                 continue;
             }
-            inject_agent_infos(a.clone(), all_agent_infos(b.clone().into()).unwrap().iter())
-                .await
-                .unwrap();
-            inject_agent_infos(b.clone(), all_agent_infos(a.clone().into()).unwrap().iter())
-                .await
-                .unwrap();
+            inject_agent_infos(
+                a.clone(),
+                all_agent_infos(b.clone().into()).await.unwrap().iter(),
+            )
+            .await
+            .unwrap();
+            inject_agent_infos(
+                b.clone(),
+                all_agent_infos(a.clone().into()).await.unwrap().iter(),
+            )
+            .await
+            .unwrap();
         }
     }
 }
@@ -204,7 +211,7 @@ fn is_expired(now: u64, info: &AgentInfoSigned) -> bool {
 }
 
 /// Dump the agents currently in the peer store
-pub fn dump_state(env: EnvRead, cell_id: Option<CellId>) -> StateQueryResult<P2pAgentsDump> {
+pub async fn dump_state(env: EnvRead, cell_id: Option<CellId>) -> StateQueryResult<P2pAgentsDump> {
     use std::fmt::Write;
     let cell_id = cell_id.map(|c| c.into_dna_and_agent()).map(|c| {
         (
@@ -212,7 +219,7 @@ pub fn dump_state(env: EnvRead, cell_id: Option<CellId>) -> StateQueryResult<P2p
             (c.1.clone(), holochain_p2p::agent_holo_to_kit(c.1)),
         )
     });
-    let agent_infos = all_agent_infos(env)?;
+    let agent_infos = all_agent_infos(env).await?;
     let agent_infos = agent_infos.into_iter().filter(|a| match &cell_id {
         Some((s, _)) => s.1 == *a.space,
         None => true,
@@ -315,7 +322,7 @@ mod tests {
             .unwrap();
 
         // - Check the same data is now in the store
-        let mut agents = all_agent_infos(env.clone().into()).unwrap();
+        let mut agents = all_agent_infos(env.clone().into()).await.unwrap();
 
         agents.sort_by(|a, b| a.agent.partial_cmp(&b.agent).unwrap());
 
