@@ -32,7 +32,7 @@ pub fn delete<'a>(
                     deletes_entry_address,
                 };
                 let header_hash = source_chain
-                    .put(header_builder, None, chain_top_ordering)
+                    .put(Some(call_context.zome.clone()), header_builder, None, chain_top_ordering)
                     .await
                     .map_err(|source_chain_error| WasmError::Host(source_chain_error.to_string()))?;
                 Ok(header_hash)
