@@ -4,9 +4,7 @@ use holochain_types::prelude::*;
 use holochain_wasmer_host::prelude::WasmError;
 use std::sync::Arc;
 use crate::core::ribosome::HostFnAccess;
-use crate::core::ribosome::EntryDefsHostAccess;
-use crate::core::ribosome::EntryDefsInvocation;
-use crate::core::ribosome::EntryDefsResult;
+use crate::core::ribosome::error::RibosomeError;
 
 pub fn zome_info(
     ribosome: Arc<impl RibosomeT>,
@@ -15,22 +13,9 @@ pub fn zome_info(
 ) -> Result<ZomeInfo, WasmError> {
     match HostFnAccess::from(&call_context.host_context()) {
         HostFnAccess{ bindings_deterministic: Permission::Allow, .. } => {
-            Ok(ZomeInfo {
-                name: call_context.zome.zome_name().clone(),
-                id: ribosome
-                    .zome_to_id(&call_context.zome)
-                    .expect("Failed to get ID for current zome"),
-                entry_defs: {
-                    match ribosome.run_entry_defs(EntryDefsHostAccess, EntryDefsInvocation).map_err(|e| WasmError::Host(e.to_string()))? {
-                        EntryDefsResult::Err(zome, error_string) => return Err(WasmError::Host(format!("{}: {}", zome, error_string))),
-                        EntryDefsResult::Defs(defs) => {
-                            match defs.get(call_context.zome.zome_name()) {
-                                Some(entry_defs) => entry_defs.clone(),
-                                None => Vec::new().into(),
-                            }
-                        },
-                    }
-                },
+            ribosome.zome_info(call_context.zome.clone()).map_err(|e| match e {
+                RibosomeError::WasmError(wasm_error) => wasm_error,
+                other_error => WasmError::Host(other_error.to_string()),
             })
         },
         _ => unreachable!(),
@@ -54,9 +39,17 @@ pub mod test {
     }
 
     #[tokio::test(flavor = "multi_thread")]
-    async fn zome_info_entry_defs() {
+    async fn zome_info() {
         let host_access = fixt!(ZomeCallHostAccess, Predictable);
         let zome_info: ZomeInfo = crate::call_test_ribosome!(host_access, TestWasm::EntryDefs, "zome_info", ()).unwrap();
+        assert_eq!(
+            zome_info.name,
+            ZomeName::new("entry_defs"),
+        );
+        assert_eq!(
+            zome_info.id,
+            ZomeId::new(0)
+        );
         assert_eq!(
             zome_info.entry_defs,
             vec![
@@ -76,5 +69,18 @@ pub mod test {
                 }
             ].into(),
         );
+        assert_eq!(
+            zome_info.extern_fns,
+            vec![
+                FunctionName::new("__allocate"),
+                FunctionName::new("__data_end"),
+                FunctionName::new("__deallocate"),
+                FunctionName::new("__heap_base"),
+                FunctionName::new("assert_indexes"),
+                FunctionName::new("entry_defs"),
+                FunctionName::new("memory"),
+                FunctionName::new("zome_info"),
+            ],
+        );
     }
 }
