@@ -177,7 +177,7 @@ pub async fn check_valid_if_dna(
 ) -> SysValidationResult<()> {
     match header {
         Header::Dna(_) => {
-            if workspace.is_chain_empty(header.author())? {
+            if workspace.is_chain_empty(header.author().clone()).await? {
                 Ok(())
             } else {
                 Err(PrevHeaderError::InvalidRoot).map_err(|e| ValidationOutcome::from(e).into())
@@ -193,7 +193,7 @@ pub async fn check_chain_rollback(
     header: &Header,
     workspace: &SysValidationWorkspace,
 ) -> SysValidationResult<()> {
-    let empty = workspace.header_seq_is_empty(header)?;
+    let empty = workspace.header_seq_is_empty(header).await?;
 
     // Ok or log warning
     if empty {
@@ -531,7 +531,13 @@ impl IncomingDhtOpSender {
         self.send_op(element, make_store_element).await
     }
     async fn send_store_entry(self, element: Element) -> SysValidationResult<()> {
-        self.send_op(element, make_store_entry).await
+        let is_public_entry = element.header().entry_type().map_or(false, |et| {
+            matches!(et.visibility(), EntryVisibility::Public)
+        });
+        if is_public_entry {
+            self.send_op(element, make_store_entry).await?;
+        }
+        Ok(())
     }
     async fn send_register_add_link(self, element: Element) -> SysValidationResult<()> {
         self.send_op(element, make_register_add_link).await
@@ -585,7 +591,7 @@ async fn check_and_hold<I: Into<AnyDhtHash> + Clone>(
         .retrieve(hash.clone(), Default::default())
         .await?
     {
-        Some(el) => Ok(Source::Network(el)),
+        Some(el) => Ok(Source::Network(el.privatized())),
         None => Err(ValidationOutcome::NotHoldingDep(hash).into()),
     }
 }
@@ -599,19 +605,12 @@ async fn check_and_hold<I: Into<AnyDhtHash> + Clone>(
 /// to return an error.
 fn make_store_element(element: Element) -> Option<(DhtOpHash, DhtOp)> {
     // Extract the data
-    let (shh, element_entry) = element.into_inner();
+    let (shh, element_entry) = element.privatized().into_inner();
     let (header, signature) = shh.into_header_and_signature();
     let header = header.into_content();
 
     // Check the entry
-    let maybe_entry_box = match element_entry {
-        ElementEntry::Present(e) => Some(e.into()),
-        // This is ok because we weren't expecting an entry
-        ElementEntry::NotApplicable | ElementEntry::Hidden => None,
-        // The element is expected to have an entry but it wasn't
-        // stored so we can't add this to incoming ops
-        ElementEntry::NotStored => return None,
-    };
+    let maybe_entry_box = element_entry.into_option().map(Box::new);
 
     // Create the hash and op
     let op = DhtOp::StoreElement(signature, header, maybe_entry_box);
